This function automatically adapts the length of a title or subtitle text so that it wraps long texts in separate lines. This is useful to avoid trimming long texts when the rendered shiny size is shorter.
autoline_shiny(session, text, plot_name, font_size = 14, n = 1.6)Character. String with wrapped values.
Shiny's session object.
Character. Text for the title or subtitle or any text to be wrapped.
Character. The name of the output plot.
Numeric. Values to help calculate a proxy of length.